#### generate dataset ###############
## load eukaryote data
d_eu <- read.csv("data_eukaryotes.csv")
# exclude entries in which genome size and cell mass are not available.
d_eu <- d_eu[is.na(d_eu$Nuc)==F,]
d_eu <- d_eu[is.na(d_eu$Mpg_pg)==F,]
## load prokaryote data
# exclude entries in which genome size and cell mass are not available.
d_pro <- read.csv("data_prokaryotes.csv")
d_pro <- d_pro[is.na(d_pro$Nuc)==F,]
d_pro <- d_pro[is.na(d_pro$Mpg_pg)==F,]

#### calculate energetic parameters #######
# qW_fW: Power per cell (fW)
# d$qWkg_W_kg * d$Mpg_pg

# qW_nuc_haploid_Mb_min_pW: Power per haploid Mb (pW)
# 1000 * d$qW_fW / d$Nuc / d$Ploidy_level_max

# qW_gene_min_fW: Power per gene (fW)
# d$qW_fW / d$Gene / d$Ploidy_level_max

# qW_genome_min_pW: Power per genome (fW)
# d$qW_fW / d$Ploidy_level_max

## generate prokaryote dataset
d <- d_pro[c("Genus_Species","NAME","Gene_Ref_Note","Mpg_pg","qWkg_W_kg","Nuc","Gene","Ploidy_level_max")]
d <- cbind(d, numeric(dim(d_pro)[[1]]))
d <- cbind(d, d_pro$qWkg_W_kg * d_pro$Mpg_pg)
d <- cbind(d, 1000 * d_pro$qWkg_W_kg * d_pro$Mpg_pg / d_pro$Nuc / d_pro$Ploidy_level_max)
d <- cbind(d, d_pro$qWkg_W_kg * d_pro$Mpg_pg / d_pro$Gene / d_pro$Ploidy_level_max)
d <- cbind(d, d_pro$qWkg_W_kg * d_pro$Mpg_pg / d_pro$Ploidy_level_max)
names(d) <- c("species_name","id","data_note","M.pg","qWkg_W_kg","genome.size","gene.number","ploidy","eukaryote","power.per.cell","power.per.haploid.Mb.pW","power.per.gene","power.per.genome")

data <- c()

sp_set <- unique(d$id)
for(sp in sp_set){
    d_sub <- subset(d,d$id == sp & d$data_note == "")
    if(dim(d_sub)[[1]] == 0){
        d_sub <- subset(d,d$id == sp)
    }
	# select the maximum mass-specific metabolic rate
    data <- rbind(data,d_sub[which(d_sub$qWkg_W_kg == max(d_sub$qWkg_W_kg))[[1]],])
}

## generate eukaryote dataset
d <- d_eu[c("Genus_Species","NAME","Gene_Ref_Note","Mpg_pg","qWkg_W_kg","Nuc","Gene","Ploidy_level_max")]
d <- cbind(d, numeric(dim(d_eu)[[1]])+1)
d <- cbind(d, d_eu$qWkg_W_kg * d_eu$Mpg_pg)
d <- cbind(d, 1000 * d_eu$qWkg_W_kg * d_eu$Mpg_pg / d_eu$Nuc / d_eu$Ploidy_level_max)
d <- cbind(d, d_eu$qWkg_W_kg * d_eu$Mpg_pg / d_eu$Gene / d_eu$Ploidy_level_max)
d <- cbind(d, d_eu$qWkg_W_kg * d_eu$Mpg_pg / d_eu$Ploidy_level_max)
names(d) <- c("species_name","id","data_note","M.pg","qWkg_W_kg","genome.size","gene.number","ploidy","eukaryote","power.per.cell","power.per.haploid.Mb.pW","power.per.gene","power.per.genome")

sp_set <- unique(d$id)
for(sp in sp_set){
    d_sub <- subset(d,d$id == sp & d$data_note == "")
    if(dim(d_sub)[[1]] == 0){
        d_sub <- subset(d,d$id == sp)
    }
    # select the maximum mass-specific metabolic rate
    data <- rbind(data,d_sub[which(d_sub$qWkg_W_kg == max(d_sub$qWkg_W_kg))[[1]],])
}

##### Phylogenetic logistic regression analysis ######### #環境パスが通っていないなどの理由でVScodeだと動かない可能性あり。ターミナルで動かすこと
library(ape)
library(rr2)
# load phylogenetic tree
tree <- read.tree("ML_phylogenetic_tree_LG_G.nwk")
tree$edge.length <- ifelse(tree$edge.length > 0,tree$edge.length,0.00001)
# Standardization
data_norm <- data.frame(data[c("species_name","eukaryote")], scale(log(data[c("M.pg","power.per.cell","power.per.haploid.Mb.pW","power.per.gene","power.per.genome","ploidy")])))
row.names(data_norm) <- data$id
data_norm <- data_norm[tree$tip.label,]
# generate model
model <- binaryPGLMM(eukaryote ~ power.per.genome + M.pg , data = data_norm, phy=tree)
# see model summary (i.e., estimate, SE, p-value, s2, etc.)
model
# see R2
R2.pred(model)
