#### generate dataset ###############
## load eukaryote data
d_eu <- read.csv("data_eukaryotes.csv")
# exclude entries in which genome size and cell mass are not available.
d_eu <- d_eu[is.na(d_eu$Nuc)==F,]
d_eu <- d_eu[is.na(d_eu$Mpg_pg)==F,]
## load prokaryote data
d_pro <- read.csv("data_prokaryotes.csv")
# exclude entries in which genome size and cell mass are not available.
d_pro <- d_pro[is.na(d_pro$Nuc)==F,]
d_pro <- d_pro[is.na(d_pro$Mpg_pg)==F,]
# remove prokaryotes whose ploidy level had not been reported in any previous studies.
#d_pro <- d_pro[d_pro$Ploidy_level_Ref != "",]

#### calculate energetic parameters #######
# power.per.cell: Power per cell (fW)
# d$qWkg_W_kg * d$Mpg_pg

# power.per.haploid.Mb.pW: Power per haploid Mb (pW)
# 1000 * d$qW_fW / d$Nuc / d$Ploidy_level_max

# power.per.gene: Power per gene (fW)
# d$qW_fW / d$Gene / d$Ploidy_level_max

# power.per.genome: Power per genome (fW)
# d$qW_fW / d$Ploidy_level_max

## generate prokaryote dataset
d <- d_pro[c("Genus_Species","NAME","Gene_Ref_Note","Mpg_pg","qWkg_W_kg","Nuc","Gene","Ploidy_level_max")]
d <- cbind(d, numeric(dim(d_pro)[[1]]))
d <- cbind(d, d_pro$qWkg_W_kg * d_pro$Mpg_pg)
d <- cbind(d, 1000 * d_pro$qWkg_W_kg * d_pro$Mpg_pg / d_pro$Nuc / d_pro$Ploidy_level_max)
d <- cbind(d, d_pro$qWkg_W_kg * d_pro$Mpg_pg / d_pro$Gene / d_pro$Ploidy_level_max)
d <- cbind(d, d_pro$qWkg_W_kg * d_pro$Mpg_pg / d_pro$Ploidy_level_max)
names(d) <- c("species_name","id","data_note","M.pg","qWkg_W_kg","genome.size","gene.number","ploidy","eukaryote","power.per.cell","power.per.haploid.Mb.pW","power.per.gene","power.per.genome")

data <- c()

sp_set <- unique(d$species_name)
for(sp in sp_set){
    d_sub <- subset(d,d$species_name == sp)
    # select the maximum mass-specific metabolic rate
    data <- rbind(data,d_sub[which(d_sub$qWkg_W_kg == max(d_sub$qWkg_W_kg))[[1]],])
}

## generate eukaryote dataset
d <- d_eu[c("Genus_Species","NAME","Gene_Ref_Note","Mpg_pg","qWkg_W_kg","Nuc","Gene","Ploidy_level_max")]
d <- cbind(d, numeric(dim(d_eu)[[1]])+1)
d <- cbind(d, d_eu$qWkg_W_kg * d_eu$Mpg_pg)
d <- cbind(d, 1000 * d_eu$qWkg_W_kg * d_eu$Mpg_pg / d_eu$Nuc / d_eu$Ploidy_level_max)
d <- cbind(d, d_eu$qWkg_W_kg * d_eu$Mpg_pg / d_eu$Gene / d_eu$Ploidy_level_max)
d <- cbind(d, d_eu$qWkg_W_kg * d_eu$Mpg_pg / d_eu$Ploidy_level_max)
names(d) <- c("species_name","id","data_note","M.pg","qWkg_W_kg","genome.size","gene.number","ploidy","eukaryote","power.per.cell","power.per.haploid.Mb.pW","power.per.gene","power.per.genome")

sp_set <- unique(d$species_name)
for(sp in sp_set){
    d_sub <- subset(d,d$species_name == sp)
    # select the maximum mass-specific metabolic rate
    data <- rbind(data,d_sub[which(d_sub$qWkg_W_kg == max(d_sub$qWkg_W_kg))[[1]],])
}

##### statistics ############################
# median values for eukaryotes
apply(data[data$eukaryote==1,c("M.pg","qWkg_W_kg","power.per.cell","ploidy","genome.size","power.per.haploid.Mb.pW","gene.number","power.per.gene","power.per.genome")],2,median)
# median values for prokaryotes
apply(data[data$eukaryote==0,c("M.pg","qWkg_W_kg","power.per.cell","ploidy","genome.size","power.per.haploid.Mb.pW","gene.number","power.per.gene","power.per.genome")],2,median)

# mena values for eukaryotes
apply(data[data$eukaryote==1,c("M.pg","qWkg_W_kg","power.per.cell","ploidy","genome.size","power.per.haploid.Mb.pW","gene.number","power.per.gene","power.per.genome")],2,mean)
# mean values for prokaryotes
apply(data[data$eukaryote==0,c("M.pg","qWkg_W_kg","power.per.cell","ploidy","genome.size","power.per.haploid.Mb.pW","gene.number","power.per.gene","power.per.genome")],2,mean)

##### Box plot (figure 1a and 1b) ######################
boxplot(log10(data$power.per.genome)~data$eukaryote, col=c("red","green"))
boxplot(log10(data$power.per.gene)~data$eukaryote, col=c("red","green"))

# Wilcoxon test
wilcox.test(log10(data$power.per.genome)~data$eukaryote)
wilcox.test(log10(data$power.per.gene)~data$eukaryote)

##### Scatter plot (figure 1c and 1d) ######################
plot(log10(data$M.pg), log10(data$power.per.genome), col=c("red","green")[data$eukaryote+1], pch=16)
plot(log10(data$M.pg), log10(data$power.per.gene), col=c("red","green")[data$eukaryote+1], pch=16)

##### Standard logistic regression analysis ############
library(rr2)
# Standardization
data_norm <- data.frame(data[c("species_name","eukaryote")], scale(log(data[c("M.pg","power.per.cell","power.per.haploid.Mb.pW","power.per.gene","power.per.genome","ploidy")])))
# generate model
model <- glm(eukaryote ~ power.per.genome , family = "binomial", data = data_norm)
# see model summary (i.e., estimate, SE, p-value, etc.)
summary(model)
# see R2
R2.pred(model)
